from . import process
from .process import Processing, FeatureExtractors
from . import io
from .core import *

# load seaborn colormaps
from seaborn import cm
del cm
